import axios from "axios";
import { generateError } from "./util.js";
const uri = process.env.REACT_APP_BACKEND_URI;
export async function getLeagueById(leagueId) {
    let leagueResponse;
    try {
        leagueResponse = await axios({
            method: "get",
            url: `${uri}/league/id/${leagueId}`,
            responseType: "json",
            withCredentials: true
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return enrichLeague(leagueResponse.data);
}
export async function getCurrentDayMatches(tournamentId) {
    let currentDayResponse;
    try {
        currentDayResponse = await axios({
            method: "get",
            url: `${uri}/match/tournamentId/${tournamentId}`,
            responseType: "json",
            withCredentials: true
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return currentDayResponse.data;
}
export async function getResultsFromDay(tournamentId, day) {
    let resultsResponse;
    try {
        resultsResponse = await axios({
            method: "get",
            url: `${uri}/match/results/tournamentId/${tournamentId}/day/${day}`,
            responseType: "json",
            withCredentials: true
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return resultsResponse.data;
}
export async function submitDayPredictions(dayPreds) {
    try {
        await axios({
            method: "put",
            url: `${uri}/match/predictions`,
            data: dayPreds,
            responseType: "json",
            withCredentials: true
        });
    }
    catch (e) {
        throw generateError(e);
    }
}
export async function authPredictionUser(token) {
    let authResponse;
    try {
        authResponse = await axios({
            method: "post",
            url: `${uri}/auth/`,
            responseType: "json",
            data: { "token": token },
            withCredentials: true
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return authResponse.data;
}
export async function getDayPredictions(userId, leagueId) {
    let dayPredsResponse;
    try {
        dayPredsResponse = await axios({
            method: "get",
            url: `${uri}/match/predictions/userId/${userId}/leagueId/${leagueId}`,
            responseType: "json",
            withCredentials: true
        });
    }
    catch (e) {
        throw generateError(e);
    }
    return dayPredsResponse.data;
}
function enrichLeague(league) {
    const ldm = getLeagueDaysMap(league.leagueDays);
    const usm = getUserTotalScoresMap(league.userScores);
    const enrichedLeague = {
        id: league.id,
        tournamentId: league.tournamentId,
        finished: league.finished,
        daysMap: ldm,
        userScores: usm,
    };
    return enrichedLeague;
}
function getUserTotalScoresMap(userScores) {
    const usm = new Map();
    userScores.forEach((us) => {
        usm.set(us.userId, us.score);
    });
    return usm;
}
function getPredictionsMap(predictions) {
    const predsMap = new Map();
    predictions.forEach((apiPrediction) => {
        const prediction = {
            matchId: apiPrediction.matchId,
            predictionTeamId: apiPrediction.predictionTeamId,
            wasCorrect: apiPrediction.wasCorrect,
        };
        predsMap.set(apiPrediction.matchId, prediction);
    });
    return predsMap;
}
function getUserDayScoresMap(userDayScores) {
    const usm = new Map();
    userDayScores.forEach((apiUserDayScore) => {
        const userDayScore = {
            userId: apiUserDayScore.userId,
            dayNumber: apiUserDayScore.dayNumber,
            dayScore: apiUserDayScore.dayScore,
            predictions: getPredictionsMap(apiUserDayScore.predictions),
        };
        usm.set(apiUserDayScore.userId, userDayScore);
    });
    return usm;
}
function getLeagueDaysMap(leagueDays) {
    const ldm = new Map();
    leagueDays.forEach((apiLeagueDay) => {
        const leagueDay = {
            day: apiLeagueDay.day,
            userScores: getUserDayScoresMap(apiLeagueDay.userDayScores),
        };
        ldm.set(apiLeagueDay.day, leagueDay);
    });
    return ldm;
}
